package com.b510.hbase.util.dao.test;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import com.b510.hbase.util.dao.HbaseDao;
import com.b510.hbase.util.dao.impl.HbaseDaoImpl;

/**
 * @author Hongten
 * @created 7 Nov 2018
 */
public class HbaseDaoTest {

	HbaseDao dao = new HbaseDaoImpl(4);

	public static final String tableName = "t_test";
	public static final String columnFamilyName = "cf1";
	public static final String[] CFs = { columnFamilyName };

	public static final String COLUMN_NAME_NAME = "name";
	public static final String COLUMN_NAME_AGE = "age";

	@Test
	public void main() {
		createTable();
		addRow();
		getRow();
		getAllRows();
		getRowsByRange();
		delRow();
		delRowsByRowKeys();
		deleteHTable();
	}

	public void createTable() {
		System.out.println("=== create table ====");
		dao.createHTable(tableName, CFs);
	}

	public void addRow() {
		System.out.println("=== insert record ====");
		dao.addRow(tableName, "12345566", columnFamilyName, COLUMN_NAME_NAME, "Hongten");
		dao.addRow(tableName, "12345566", columnFamilyName, COLUMN_NAME_AGE, "22");

		dao.addRow(tableName, "12345567", columnFamilyName, COLUMN_NAME_NAME, "Tom");
		dao.addRow(tableName, "12345567", columnFamilyName, COLUMN_NAME_AGE, "25");

		dao.addRow(tableName, "12345568", columnFamilyName, COLUMN_NAME_NAME, "Jone");
		dao.addRow(tableName, "12345568", columnFamilyName, COLUMN_NAME_AGE, "30");

		dao.addRow(tableName, "12345569", columnFamilyName, COLUMN_NAME_NAME, "Jobs");
		dao.addRow(tableName, "12345569", columnFamilyName, COLUMN_NAME_AGE, "24");
	}

	public void getRow() {
		System.out.println("=== get record ====");
		dao.getRow(tableName, "12345566");
	}

	public void getAllRows() {
		System.out.println("=== scan table ====");
		dao.getAllRows(tableName);
	}

	public void getRowsByRange() {
		System.out.println("=== scan record by giving range ====");
		// it will return the '12345567' and '12345568' rows.
		dao.getRowsByRange(tableName, "12345567", "12345569");
	}

	public void delRow() {
		System.out.println("=== delete record ====");
		dao.delRow(tableName, "12345568");
		// only '12345567' row.
		getRowsByRange();
	}

	public void delRowsByRowKeys() {
		System.out.println("=== delete batch records ====");
		List<String> rowKeys = new ArrayList<String>();
		rowKeys.add("12345566");
		rowKeys.add("12345569");
		dao.delRowsByRowKeys(tableName, rowKeys);
		// can not find the '12345566' and '12345569'
		getAllRows();
	}

	public void deleteHTable() {
		System.out.println("=== delete table ====");
		dao.deleteHTable(tableName);
	}
}
